XKB Considerations
================================================================================

> If you want custom keymaps on your machine, switch to Wayland (and/or fix any
> remaining issues preventing you from doing so) instead of hoping this will
> ever work on X.

— [Peter Hutterer](https://who-t.blogspot.com/2020/09/no-user-specific-xkb-configuration-in-x.html)
- [User-configuration for Wayland](https://xkbcommon.org/doc/current/md_doc_2user-configuration.html)



Resources
--------------------------------------------------------------------------------

XKB is a tricky piece of software.
The following resources might be helpful if you want to dig in:

- [Ivan Pascal's XKB documentation](https://web.archive.org/web/20190724015820/http://pascal.tsu.ru/en/xkb/)
- [An Unreliable Guide to XKB Configuration](https://www.charvolant.org/doug/xkb/html/)
- [How to enhance XKB configuration](How to enhance XKB configuration)
- xkbcommon:
  - [XKB introduction](https://xkbcommon.org/doc/current/xkb-intro.html)
  - [The XKB keymap text format, V1](https://xkbcommon.org/doc/current/keymap-text-format-v1.html)
- ArchLinux wiki:
  - [X keyboard extension](https://wiki.archlinux.org/title/X_keyboard_extension)
  - [Xorg/Keyboard configuration](https://wiki.archlinux.org/title/Xorg/Keyboard_configuration)
